@@ -201,8 +201,7 @@ void CProcessListTable::refresh()
     ensureVisible(0, 0);  
   query()->freeResult();
   setNumRows(0);
-  if (sorting())
-    horizontalHeader()->setSortIndicator( -1 );  
+  horizontalHeader()->setSortIndicator( -1 );  
   if (query()->exec(sql))
   {
     uint num_rows = qry->numRows();
@@ -259,6 +258,7 @@ void CProcessListTable::refresh()
     verticalScrollBar()->setValue(scroll);
   }  
   setBlocked(false);
+  applyLastSort();
 }
 
 
@@ -466,6 +466,7 @@ void CServerStatusTable::refresh()
     verticalScrollBar()->setValue(scroll);
   }
   setBlocked(false);
+  applyLastSort();
 }
 
 
@@ -604,6 +605,7 @@ CAdministrationWindow::CAdministrationWindow(QWidget* parent,  CMySQLServer *m)
   (void)statusBar();
 
   blocked = false;
+  myApp()->incCritical();
   setCaption("[" + m->connectionName() + "] " + trUtf8("Administration Panel"));
   setIcon(getPixmapIcon("applicationIcon"));
   enableMessageWindow(true);  
@@ -850,6 +852,7 @@ void CAdministrationWindow::refresh()
 
 CAdministrationWindow::~CAdministrationWindow()
 {
+  myApp()->decCritical();
   if (delete_mysql)
     delete m_mysql;
   delete flush_menu;
