@@ -130,12 +130,13 @@ CQuerySet::CQuerySet(CQueryWindow *p, uint id, int querytype, const QString &db,
   is_force = true;
   my_parent = p;
   do_cancel = false;
+  is_first = true;
   default_database = QString::null;
   explain_rows = 0;
   explain_cols = 0;
   
   mysql_server = new CMySQLServer(my_parent->mysql()->connectionName(), my_parent->messagePanel());
-  mysql_server->connect();  
+  mysql_server->connect();
 
   m_query = new CMySQLQuery(mysql_server->mysql());
   m_query->setAutoDelete(false);
@@ -190,6 +191,7 @@ void CQuerySet::enableDeleteAction(bool b)
 
 void CQuerySet::setDefaultDatabase(const QString &s)
 {
+  default_db = s;
   if (default_database != s)
   {
     default_table = QString::null;
@@ -287,17 +289,39 @@ bool CQuerySet::execQuery(const QString &query_str)
   int check_pending_event = 0;
 #endif
   
+  finished_event * finished_evt = new finished_event;
+  finished_evt->query_type = QString::null;
+  finished_evt->read_only = true;
+  finished_evt->ret = false;
+
+  if (!mysql_server->isConnected())
+  {
+    bool e = mysql_server->mysql()->hasEmitErrors();
+    if (is_first)
+      mysql_server->mysql()->setEmitErrors(false);
+    mysql_server->connect();
+    if (is_first)
+      mysql_server->mysql()->setEmitErrors(e);
+    if (!mysql_server->isConnected())
+    {
+      QCustomEvent *event = new QCustomEvent(FINISHED);
+      event->setData(finished_evt);
+      QApplication::postEvent(this, event);
+      is_first = false;
+      return false;
+    }
+    else
+      setDefaultDatabase(default_db);
+  }
+
+  is_first = false;
+
   QString qry = query_str;
   bool query_ok = false;
   bool isquoted = false;
   bool new_tab = false;
   bool multiple_queries = false;
 
-  finished_event * finished_evt = new finished_event;
-  finished_evt->query_type = QString::null;
-  finished_evt->read_only = true;
-  finished_evt->ret = false;
-
   explain_rows = 0;
   explain_cols = 0;
  
@@ -386,7 +410,6 @@ bool CQuerySet::execQuery(const QString &query_str)
                 query_ok = query()->exec(mysql()->mysql()->codec()->fromUnicode(q));
                 if (i < qry.length() - 1)
                   multiple_queries = true;
-
                 if (query_ok && query()->returnedResults())
                 {
                   if (!new_tab)
@@ -647,8 +670,8 @@ void CQuerySet::executeQuery()
   results_table->reset();
   my_parent->showResultsPanel(true);
 
-#ifndef QT_THREAD_SUPPORT
-  execQuery(query_editor->hasSelectedText() ? query_editor->selectedText() : query_editor->text());
+#ifndef QT_THREAD_SUPPORT    
+  execQuery(query_editor->hasSelectedText() ? query_editor->selectedText() : query_editor->text());    
 #else
   if (!thread->running())
   {
@@ -975,33 +998,35 @@ void CQueryWindow::init(const QString &connection_name, int querytype, ushort di
   viewResultTabsMenu = new QPopupMenu(this);
 
   CAction *viewResultTabFirstAction = new CAction(tr("First"), getPixmapIcon("firstIcon"), tr("&First"),
-    Qt::ALT + Qt::Key_1, this, "viewResultTabFirstAction");
+    Qt::CTRL + Qt::Key_F7, this, "viewResultTabFirstAction");
   viewResultTabFirstAction->setParentMenuText(tr("View | Result Tabs"));
   connect(viewResultTabFirstAction, SIGNAL(activated()), results_tab, SLOT(first()));
   viewResultTabFirstAction->addTo(viewResultTabsMenu);
 
   CAction *viewResultTabBackAction = new CAction(tr("Back"), getPixmapIcon("backIcon"), tr("&Back"),
-    Qt::ALT + Qt::Key_2, this, "viewResultTabBackAction");
+    Qt::CTRL + Qt::Key_F8, this, "viewResultTabBackAction");
   viewResultTabBackAction->setParentMenuText(tr("View | Result Tabs"));
   connect(viewResultTabBackAction, SIGNAL(activated()), results_tab, SLOT(back()));
   viewResultTabBackAction->addTo(viewResultTabsMenu);
 
   CAction *viewResultTabPreviousAction = new CAction(tr("Toggle Previous"), getPixmapIcon("toggleIcon"), tr("&Toggle Previous"),
-    Qt::ALT + Qt::Key_3, this, "viewResultTabPreviousAction");
+    Qt::CTRL + Qt::Key_F9, this, "viewResultTabPreviousAction");
   viewResultTabPreviousAction->setParentMenuText(tr("View | Result Tabs"));
   connect(viewResultTabPreviousAction, SIGNAL(activated()), results_tab, SLOT(toggle()));
   viewResultTabPreviousAction->addTo(viewResultTabsMenu);
+  /*
   QAccel *resultsTabPreviousAccel = new QAccel(this);
   resultsTabPreviousAccel->connectItem(resultsTabPreviousAccel->insertItem(Qt::SHIFT + Qt::Key_Space), results_tab, SLOT(toggle()));
+  */
 
   CAction *viewResultTabNextAction = new CAction(tr("Next"), getPixmapIcon("nextIcon"), tr("&Next"),
-    Qt::ALT + Qt::Key_4, this, "viewResultTabNextAction");
+    Qt::CTRL + Qt::Key_F10, this, "viewResultTabNextAction");
   viewResultTabNextAction->setParentMenuText(tr("View | Result Tabs"));
   connect(viewResultTabNextAction, SIGNAL(activated()), results_tab, SLOT(next()));
   viewResultTabNextAction->addTo(viewResultTabsMenu);
 
   CAction *viewResultTabLastAction = new CAction(tr("Last"), getPixmapIcon("lastIcon"), tr("&Last"),
-    Qt::ALT + Qt::Key_5, this, "viewResultTabLastAction");
+    Qt::CTRL + Qt::Key_F11, this, "viewResultTabLastAction");
   viewResultTabLastAction->setParentMenuText(tr("View | Result Tabs"));
   connect(viewResultTabLastAction, SIGNAL(activated()), results_tab, SLOT(last()));
   viewResultTabLastAction->addTo(viewResultTabsMenu);
@@ -1523,7 +1548,7 @@ void CQueryWindow::executeQuery()
   CQuerySet *q = currentQuerySet();    
   if (q && queryExecuteAction->isEnabled())
     if (!q->isBusy())
-      q->executeQuery();    
+      q->executeQuery();
 }
 
 void CQueryWindow::cancelQuery()
@@ -1542,9 +1567,16 @@ void CQueryWindow::insertRecord()
 
 void CQueryWindow::deleteRecord()
 {
-  CQuerySet *q = currentResultSet();
-  if (q)
-    q->resultsTable()->deleteRecord();
+  CQuerySet *r = currentResultSet();
+  if (r)
+    r->resultsTable()->deleteRecord();
+  else
+  {
+    CQuerySet *q = currentQuerySet();
+    if (q)
+      if (q->queryEditor()->hasFocus())
+        q->queryEditor()->doKeyboardAction(QTextEdit::ActionDelete);
+  }
 }
 
 void CQueryWindow::queryWindowOptions()
