@@ -114,11 +114,11 @@ void CQueryWindowOptionsTab::languageChange()
 
 void CQueryWindowOptionsTab::setDefaultValues(CConfig *cfg)
 {
-  queryNewTab->setChecked(strtobool(cfg->readStringEntry("Query New Tab", "false")));
+  queryNewTab->setChecked(strtobool(cfg->readStringEntry("Query New Tab", "true")));
   followQueryTab->setChecked(strtobool(cfg->readStringEntry("Follow Query Tab", "true")));
   followResultsTab->setChecked(strtobool(cfg->readStringEntry("Follow Results Tab", "false")));
   maxResults->setValue(cfg->readNumberEntry("Max Results to Save", 10));
-  ((QRadioButton *)multipleQueries->find(cfg->readNumberEntry("Multiple Query Options", 0)))->setChecked(true);
+  ((QRadioButton *)multipleQueries->find(cfg->readNumberEntry("Multiple Query Options", 1)))->setChecked(true);
 }
 
 bool CQueryWindowOptionsTab::save(CConfig *cfg)
